VolumeDownButton class final

The physical volume down button.

Inheritance
Annotations

Constructors

VolumeDownButton()
The physical volume down button.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
Serialization key for this button type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override